package com.example.bmicalculator

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.animation.*
import androidx.compose.animation.core.*
import androidx.compose.foundation.*
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            MaterialTheme {
                Surface(
                    modifier = Modifier.fillMaxSize(),
                    color = MaterialTheme.colorScheme.background
                ) {
                    BMICalculator()
                }
            }
        }
    }
}

@Composable
fun BMIGradientButton(
    text: String,
    onClick: () -> Unit,
    modifier: Modifier = Modifier
) {
    Button(
        onClick = onClick,
        modifier = modifier
            .shadow(
                elevation = 8.dp,
                shape = RoundedCornerShape(16.dp)
            ),
        contentPadding = PaddingValues(0.dp),
        colors = ButtonDefaults.buttonColors(containerColor = Color.Transparent)
    ) {
        Box(
            modifier = Modifier
                .background(
                    brush = Brush.horizontalGradient(
                        colors = listOf(
                            Color(0xFF6B8FFF),
                            Color(0xFF3461FF)
                        )
                    )
                )
                .padding(horizontal = 32.dp, vertical = 16.dp),
            contentAlignment = Alignment.Center
        ) {
            Text(
                text = text,
                fontSize = 18.sp,
                fontWeight = FontWeight.Bold,
                color = Color.White
            )
        }
    }
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun BMICalculator() {
    var weight by remember { mutableStateOf("") }
    var height by remember { mutableStateOf("") }
    var bmiResult by remember { mutableStateOf(0f) }
    var bmiCategory by remember { mutableStateOf("") }
    var isMetric by remember { mutableStateOf(true) }
    var showResult by remember { mutableStateOf(false) }

    val scrollState = rememberScrollState()

    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(
                brush = Brush.verticalGradient(
                    colors = listOf(
                        Color(0xFFF8F9FF),
                        Color(0xFFE8ECFD)
                    )
                )
            )
    ) {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(24.dp)
                .verticalScroll(scrollState),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.spacedBy(16.dp)
        ) {
            // Header
            Text(
                text = "BMI Calculator",
                fontSize = 32.sp,
                fontWeight = FontWeight.Bold,
                color = Color(0xFF1B1B1B),
                modifier = Modifier.padding(vertical = 24.dp)
            )

            // Unit Toggle Card
            Card(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(vertical = 8.dp),
                shape = RoundedCornerShape(16.dp),
                colors = CardDefaults.cardColors(containerColor = Color.White)
            ) {
                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(8.dp),
                    horizontalArrangement = Arrangement.SpaceEvenly,
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    Text(
                        text = "USC",
                        fontSize = 16.sp,
                        color = if (!isMetric) Color(0xFF3461FF) else Color.Gray
                    )
                    Switch(
                        checked = isMetric,
                        onCheckedChange = {
                            isMetric = it
                            weight = ""
                            height = ""
                            showResult = false
                        },
                        colors = SwitchDefaults.colors(
                            checkedThumbColor = Color(0xFF3461FF),
                            checkedTrackColor = Color(0xFFD0D9FF)
                        )
                    )
                    Text(
                        text = "SI",
                        fontSize = 16.sp,
                        color = if (isMetric) Color(0xFF3461FF) else Color.Gray
                    )
                }
            }

            // Input Fields
            Card(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(vertical = 8.dp),
                shape = RoundedCornerShape(16.dp),
                colors = CardDefaults.cardColors(containerColor = Color.White)
            ) {
                Column(
                    modifier = Modifier.padding(16.dp),
                    verticalArrangement = Arrangement.spacedBy(16.dp)
                ) {
                    OutlinedTextField(
                        value = weight,
                        onValueChange = { weight = it },
                        label = { Text(if (isMetric) "Weight (kg)" else "Weight (lbs)") },
                        keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Decimal),
                        modifier = Modifier.fillMaxWidth(),
                        shape = RoundedCornerShape(12.dp)
                    )

                    OutlinedTextField(
                        value = height,
                        onValueChange = { height = it },
                        label = { Text(if (isMetric) "Height (cm)" else "Height (inches)") },
                        keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Decimal),
                        modifier = Modifier.fillMaxWidth(),
                        shape = RoundedCornerShape(12.dp)
                    )
                }
            }

            Spacer(modifier = Modifier.height(8.dp))

            BMIGradientButton(
                text = "Calculate BMI",
                onClick = {
                    try {
                        val weightValue = weight.toFloat()
                        val heightValue = height.toFloat()

                        bmiResult = if (isMetric) {
                            weightValue / ((heightValue / 100) * (heightValue / 100))
                        } else {
                            703 * weightValue / (heightValue * heightValue)
                        }

                        bmiCategory = when {
                            bmiResult < 18.5f -> "Underweight"
                            bmiResult < 25f -> "Normal weight"
                            bmiResult < 30f -> "Overweight"
                            else -> "Obese"
                        }

                        showResult = true
                    } catch (e: NumberFormatException) {
                        showResult = false
                    }
                },
                modifier = Modifier.fillMaxWidth()
            )

            AnimatedVisibility(
                visible = showResult,
                enter = fadeIn() + expandVertically(),
                exit = fadeOut() + shrinkVertically()
            ) {
                Column(
                    modifier = Modifier.fillMaxWidth(),
                    verticalArrangement = Arrangement.spacedBy(16.dp)
                ) {
                    // Result Card
                    Card(
                        modifier = Modifier.fillMaxWidth(),
                        shape = RoundedCornerShape(16.dp),
                        colors = CardDefaults.cardColors(
                            containerColor = when (bmiCategory) {
                                "Normal weight" -> Color(0xFFE7F5E8)
                                "Underweight" -> Color(0xFFFFF4E0)
                                "Overweight" -> Color(0xFFFFECDD)
                                else -> Color(0xFFFFE5E5)
                            }
                        )
                    ) {
                        Column(
                            modifier = Modifier.padding(24.dp),
                            horizontalAlignment = Alignment.CenterHorizontally
                        ) {
                            Text(
                                text = "Your BMI",
                                fontSize = 20.sp,
                                color = Color.DarkGray
                            )
                            Text(
                                text = String.format("%.1f", bmiResult),
                                fontSize = 48.sp,
                                fontWeight = FontWeight.Bold,
                                color = when (bmiCategory) {
                                    "Normal weight" -> Color(0xFF2E7D32)
                                    "Underweight" -> Color(0xFFFFA000)
                                    "Overweight" -> Color(0xFFF57C00)
                                    else -> Color(0xFFD32F2F)
                                },
                                modifier = Modifier.padding(vertical = 8.dp)
                            )
                            Text(
                                text = bmiCategory,
                                fontSize = 24.sp,
                                fontWeight = FontWeight.Medium,
                                color = when (bmiCategory) {
                                    "Normal weight" -> Color(0xFF2E7D32)
                                    "Underweight" -> Color(0xFFFFA000)
                                    "Overweight" -> Color(0xFFF57C00)
                                    else -> Color(0xFFD32F2F)
                                }
                            )
                        }
                    }

                    // BMI Categories Reference
                    Card(
                        modifier = Modifier.fillMaxWidth(),
                        shape = RoundedCornerShape(16.dp),
                        colors = CardDefaults.cardColors(containerColor = Color.White)
                    ) {
                        Column(
                            modifier = Modifier.padding(24.dp)
                        ) {
                            Text(
                                text = "BMI Categories",
                                fontSize = 20.sp,
                                fontWeight = FontWeight.Bold,
                                modifier = Modifier.padding(bottom = 16.dp)
                            )
                            CategoryRow("Underweight", "< 18.5", Color(0xFFFFA000))
                            CategoryRow("Normal weight", "18.5 - 24.9", Color(0xFF2E7D32))
                            CategoryRow("Overweight", "25 - 29.9", Color(0xFFF57C00))
                            CategoryRow("Obese", "≥ 30", Color(0xFFD32F2F))
                        }
                    }
                }
            }
        }
    }
}

@Composable
fun CategoryRow(category: String, range: String, color: Color) {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .padding(vertical = 8.dp),
        horizontalArrangement = Arrangement.SpaceBetween,
        verticalAlignment = Alignment.CenterVertically
    ) {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.spacedBy(8.dp)
        ) {
            Box(
                modifier = Modifier
                    .size(12.dp)
                    .clip(CircleShape)
                    .background(color)
            )
            Text(
                text = category,
                fontSize = 16.sp,
                color = Color.DarkGray
            )
        }
        Text(
            text = range,
            fontSize = 16.sp,
            color = Color.Gray
        )
    }
}